package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiDrillRecord;

/**
 * 演练实施记录 数据层
 */
@Mapper
public interface BusiDrillRecordMapper {

    /**
     * 查询演练实施记录
     * @param guid 查询条件
     * @return 演练实施记录
     */
    BusiDrillRecord selectBusiDrillRecordByGuid(String guid);

    /**
     * 查询演练实施记录列表
     * @param busiDrillRecord 查询条件
     * @return 演练实施记录集合
     */
    List<BusiDrillRecord> selectBusiDrillRecordList(BusiDrillRecord busiDrillRecord);

    /**
     * 新增演练实施记录
     * @param busiDrillRecord 演练实施记录
     * @return 影响行数
     */
    int insertBusiDrillRecord(BusiDrillRecord busiDrillRecord);

    /**
     * 修改演练实施记录
     * @param busiDrillRecord 演练实施记录
     * @return 影响行数
     */
    int updateBusiDrillRecord(BusiDrillRecord busiDrillRecord);

    /**
     * 删除演练实施记录
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiDrillRecordByGuid(String guid);

    /**
     * 批量删除演练实施记录
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiDrillRecordByGuids(String[] guids);
}
